//Inicialização do script para todos os tipos de pagamento
(function ($) {
    Drupal.behaviors.commercePagseguroTransparent = {
        attach: function (context, settings) {

            //Elimina as chamadas desse scrip por outros elementos que não o document. Esse script estava sendo chamado
            //pelo administrator menu e outro módulo.
            if (context !== document) {
                return;
            }

            //Cria a div do overlay do pagamento sendo processado
            $('body').once('loadingWrapper', function () {
                $("body").append("<div id='checkout_loading_wrapper' style='display: none'><div id='checkout_loading'><span id='checkout-image'></span><span id='checkout-text'>O seu pagamento está sendo processado. Isso pode demorar um pouco. Por Favor, Aguarde...</span></div></div>");
                //Esconde a div criada. Ela só será mostrada quando clicar no botão de pagar
                $("#checkout_loading_wrapper").hide();
            });
            
            // Chamada de pagamento por cartão de crédito e boleto, de acordo
            // com a opção selecionada pelo usuário
            $(document).on('click', '#edit-continue', function( event ){
                // Getting variables session passed on commerce_pagseguro_tranp.module on commerce_pagseguro_transp_submit_form()
                var session = Drupal.settings.commercePagseguroTransp.sessionId;
                PagSeguroDirectPayment.setSessionId(session);

                //Atribuindo o sender_hash
                var hash = PagSeguroDirectPayment.getSenderHash();
                $('#sender_hash').val(hash);

                if ($('#edit-commerce-payment-payment-method-pagseguro-creditcardcommerce-payment-pagseguro-creditcard').is(":checked")) {
                    event.preventDefault();
                    $("#checkout_loading_wrapper").show();
                    //Evita o submit default
                    setCreditCardToken();
                }
            });

            //Passa a quantidade de parcelas e o valor da parcela para os formulários
            $("#edit-commerce-payment-payment-details-installments").change(function () {
                //Passa a quantidade de parcelas e o valor da parcela para os formulários
                var e = document.getElementById("edit-commerce-payment-payment-details-installments");

                if (e) {
                    var option = e.options[e.selectedIndex];
                    $('#installment_amount').val(option.getAttribute('installmentAmount'));
                    $('#installments_qty').val(option.getAttribute('value'));
                }
            });

            //Remove o atributo name dos dados sensíveis
            $('#edit-commerce-payment-payment-details-card-number').removeAttr('name');
            $('#edit-commerce-payment-payment-details-security-code').removeAttr('name');
            $('#edit-commerce-payment-payment-details-card-expiration-month').removeAttr('name');
            $('#edit-commerce-payment-payment-details-card-expiration-year').removeAttr('name');

            $('#edit-commerce-payment-payment-details-card-number').once('paymentDetails', function() {
                $( "#edit-commerce-payment-payment-details-card-number" ).keyup(function() {
                    guessingPaymentMethod('keyup');
                });

                $( "#edit-commerce-payment-payment-details-card-number" ).change(function() {
                    guessingPaymentMethod('change');
                });
            });

            //obter bandeira do cartão
            function guessingPaymentMethod(event) {
                var ccNumber = document.querySelector('#edit-commerce-payment-payment-details-card-number').value;
                if ((event === 'keyup' && ccNumber.length === 6) || (event === 'change' && ccNumber.length >= 6)) {
                    if (!$("#card-brand").length) {
                        var bin = getBin();
                        PagSeguroDirectPayment.getBrand({
                            cardBin: bin,
                            success: function (response) {
                                setPaymentMethodInfo(response);
                                setInstallmentInfo();
                            },
                            error: function (response) {
                                alert('Número do cartão inválido.');
                            }
                        });
                    }
                } else if ((event === 'keyup' || event === 'change') && ccNumber.length < 6) {
                    $('#card-brand').remove();
                    clearOptions();
                }
            }

            //Clear Options of Installments select
            function clearOptions() {
                var bin = getBin();
                if (bin.length < 6) {
                    var selectorInstallments = document.querySelector("#edit-commerce-payment-payment-details-installments"),
                        fragment = document.createDocumentFragment(),
                        option = new Option("-- Select an option --", '');

                    selectorInstallments.options.length = 0;
                    fragment.appendChild(option);
                    selectorInstallments.appendChild(fragment);
                    selectorInstallments.setAttribute('disabled', 'disabled');
                }
            }

            function setCreditCardToken() {
                var param = {
                    cardNumber: $('#edit-commerce-payment-payment-details-card-number').val(),
                    cvv: $('#edit-commerce-payment-payment-details-security-code').val(),
                    expirationMonth: $('#edit-commerce-payment-payment-details-card-expiration-month').val(),
                    expirationYear: $('#edit-commerce-payment-payment-details-card-expiration-year').val(),
                    success: function(response) {
                        $('#token').val(response.card.token);
                        var form = document.querySelector('#commerce-checkout-form-review');
                        if (!form) {
                            form = document.querySelector('#commerce-checkout-form-checkout');
                        }
                        form.submit();

                        $("#checkout_loading_wrapper").hide();
                    },
                    error: function(response) {
                        payError(response);
                        $('#checkout_loading_wrapper').hide();
                        // $('#edit-continue')
                        $('.checkout-processing').addClass('checkout-processing element-invisible')
                        //tratamento do erro
                    }
                };
                PagSeguroDirectPayment.createCardToken(param);
            }

            //pega o número do cartão sem formatação
            function getBin() {
                var ccNumber = document.querySelector('#edit-commerce-payment-payment-details-card-number');
                if (ccNumber != null) {
                    return ccNumber.value.replace(/[ .-]/g, '').slice(0, 6);
                }
            }


            /* Criando uma div para mostrar a bandeira do cartão digitado. Depois chama  a função
            para trazer as opções de parcelamento */
            function setPaymentMethodInfo(response) {
                $('#payment_method_id').val(response['brand']['name']);

                //Cria uma div com a bandeira do cartão selecionado depoois do input do número do cartão
                $('#edit-commerce-payment-payment-details-card-number').after("<div id='card-brand' class='" + response['brand']['name'] + "'></div>");
            }

            /* De acordo com o cartão escolhido, verifica as opções de parcelamento.
            Preenche o select com essas opções.
            */
            function setInstallmentInfo() {

                //Pega o valor do pedido que é passado ao Drupal Behaviors no momento da criação formulário do cartão
                amount = Drupal.settings.commercePagseguroTransp.amount;
                PagSeguroDirectPayment.getInstallments({
                    amount: amount,
                    brand: $('#payment_method_id').val,
                    maxInstallmentNoInterest: 2,
                    success: function (response) {
                        var selectorInstallments = document.querySelector("#edit-commerce-payment-payment-details-installments"),
                            fragment = document.createDocumentFragment();

                        selectorInstallments.options.length = 0;
                        selectorInstallments.options.selectedIndex = 0;
                        //
                        // $('#edit-commerce-payment-payment-details-installments').append($('<option>', {
                        //     value: '',
                        //     text: '-- Select an option --'
                        // }));

                        branding = response.installments;
                        for (var key in branding) {
                            if (branding.hasOwnProperty(key)) {
                                keys = branding[key];
                            }
                        }

                        if (keys.length > 0) {
                            var txtSingularPlural = 'parcela';

                            for (var i = 0; i < keys.length; i++) {
                                if (keys[i].quantity > 1) {
                                    txtSingularPlural = 'parcelas';
                                }
                                txt = keys[i].quantity + ' ' + txtSingularPlural + ' de R$' + numberToCurrency(keys[i].installmentAmount, 2, ',', '.') + ' (R$' + numberToCurrency(keys[i].totalAmount, 2, ',', '.') + ')';
                                option = new Option(txt, keys[i].quantity);
                                //Adiciona o valor da parcela como um atributo da opção, pois será necessário saber quando for enviar o pedido.
                                option.setAttribute('installmentAmount', keys[i].installmentAmount);
                                fragment.appendChild(option);
                            }
                            selectorInstallments.appendChild(fragment);
                            selectorInstallments.removeAttribute('disabled');
                        }
                    },
                    error: function (response) {
                        //alert('Deu erro!');
                    }
                });
            }

            /* Chamada quando o token do cartão de crédito é gerado com sucesso. Cria um input hidden
            para colocar o valor do token dentro e passar via post */
            function paySuccess(response) {
                // var form = document.querySelector('#commerce-checkout-form-checkout');
                // if (!form) {
                //     form = document.querySelector('#commerce-checkout-form-review');
                // }
                // var form = document.querySelector('#commerce-checkout-form-checkout');

                // if (response != null) {
                //     //Atribuindo o token
                //     $('#token').val(response.card.token);
                // }

                //Chama o submit para capturar esses resultados no php
                // $("form").submit();
                // form.submit();
            }

            function payError(response) {
                console.log(response);
                $("#checkout_loading_wrapper").hide();
                //Tratando os erros na criação do token do cartão
                erroMessages = '<ul>';
                cause = response.errors;
                for (var key in cause) {
                    if (!cause.hasOwnProperty(key)) {
                        continue;
                    }
                    switch(key) {
                        case '10000':
                            erroMessages += "<li>Bandeira do Cartão Inválida.</li>";
                            $("#edit-commerce-payment-payment-details-card-number").addClass("error");
                            break;
                        case '10001':
                            erroMessages += "<li>Número do cartão de crédito com o tamanho inválido.</li>";
                            $("#edit-commerce-payment-payment-details-card-number").addClass("error");
                            break;
                        case '10002':
                            erroMessages += "<li>Data com um formato inválido.</li>";
                            $("#edit-commerce-payment-payment-details-card-expiration-month").addClass("error");
                            $("#edit-commerce-payment-payment-details-card-expiration-year").addClass("error");
                            break;
                        case '10003':
                            erroMessages += "<li>Código de segurança inválido.</li>";
                            $("#edit-commerce-payment-payment-details-security-code").addClass("error");
                            break;
                        case '10004':
                            erroMessages += "<li>O Código de Segurança é obrigatório.</li>";
                            $("#edit-commerce-payment-payment-details-security-code").addClass("error");
                            break;
                        case '10006':
                            erroMessages += "<li>Código de Segurança com o tamanho inválido.</li>";
                            $("#edit-commerce-payment-payment-details-security-code").addClass("error");
                            break;
                        default:
                            erroMessages += "<li>" + cause[key] + ".</li>";
                            break;
                    }
                }

                erroMessages += '</ul>';
                if ($("#card-error").length) {
                    $('#card-error-messages').remove();
                    $('#card-error').append('<div id="card-error-messages">' + erroMessages + '</div>');
                }
                else {
                    $("#edit-commerce-payment").after('<div class="container"><div id="card-error" class="alert alert-block alert-danger messages error"><div id="card-error-messages">' + erroMessages + '</div></div></div>');
                }

                $('html, body').animate({
                    scrollTop: $("#card-error").offset().top
                }, 200);
            }

            /*
            * n = numero a converter
            c = numero de casas decimais
            d = separador decimal
            t = separador milhar
            */
            function numberToCurrency(n, c, d, t) {
                c = isNaN(c = Math.abs(c)) ? 2 : c, d = d == undefined ? "," : d, t = t == undefined ? "." : t, s = n < 0 ? "-" : "", i = parseInt(n = Math.abs(+n || 0).toFixed(c)) + "", j = (j = i.length) > 3 ? j % 3 : 0;
                return s + (j ? i.substr(0, j) + t : "") + i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + t) + (c ? d + Math.abs(n - i).toFixed(c).slice(2) : "");
            };
        }
    }
}(jQuery));